@@ -8,12 +8,12 @@
 # modify it under the terms of the GNU General Public License
 # as published by the Free Software Foundation; either version 2
 # of the License, or (at your option) any later version.
-# 
+#
 # Linaro Image Tools is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-# 
+#
 # You should have received a copy of the GNU General Public License
 # along with Linaro Image Tools; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
@@ -28,6 +28,7 @@ from linaro_image_tools.hwpack.hardwarepack_format import (
     HardwarePackFormatV2,
     )
 
+
 class HwpackConfigError(Exception):
     pass
 
@@ -84,14 +85,12 @@ class Config(object):
     SAMSUNG_ENV_LEN_KEY = 'samsung_env_len'
     SAMSUNG_BL2_LEN_KEY = 'samsung_bl2_len'
 
-
     DEFINED_PARTITION_LAYOUTS = [
         'bootfs16_rootfs',
         'bootfs_rootfs',
         'reserved_bootfs_rootfs',
         ]
 
-
     def __init__(self, fp):
         """Create a Config.
 
@@ -167,7 +166,7 @@ class Config(object):
             # When this code no longer supports 1.0, it effectively makes
             # explicitly specifying format in hwpack files mandatory.
             format_string = "1.0"
-        
+
         if format_string == '1.0':
             return HardwarePackFormatV1()
         elif format_string == '2.0':
@@ -239,7 +238,7 @@ class Config(object):
 
     @property
     def serial_tty(self):
-        """/dev device name of the serial console for this kernel 
+        """/dev device name of the serial console for this kernel
 
         A str.
         """
@@ -280,7 +279,7 @@ class Config(object):
 
     @property
     def kernel_addr(self):
-        """address where u-boot should load the kernel 
+        """address where u-boot should load the kernel
 
         An int.
         """
@@ -288,7 +287,7 @@ class Config(object):
 
     @property
     def initrd_addr(self):
-        """address where u-boot should load the kernel 
+        """address where u-boot should load the kernel
 
         An int.
         """
@@ -328,9 +327,9 @@ class Config(object):
 
     @property
     def partition_layout(self):
-        """bootfs16_rootfs, bootfs_rootfs and reserved_bootfs_rootfs; 
-        controls what kind of SD card partition layout we should use when 
-        writing images 
+        """bootfs16_rootfs, bootfs_rootfs and reserved_bootfs_rootfs;
+        controls what kind of SD card partition layout we should use when
+        writing images
 
         A str.
         """
@@ -338,7 +337,7 @@ class Config(object):
 
     @property
     def mmc_id(self):
-        """which MMC drive contains the boot filesystem 
+        """which MMC drive contains the boot filesystem
 
         An int.
         """
@@ -594,7 +593,7 @@ class Config(object):
         if dtb_file is not None:
             self._assert_matches_pattern(
                 self.GLOB_REGEX, dtb_file, "Invalid path: %s" % dtb_file)
-        
+
     def _validate_extra_boot_options(self):
         # Optional and tricky to determine a valid pattern.
         pass
@@ -611,7 +610,6 @@ class Config(object):
             self._assert_matches_pattern(
                 self.PATH_REGEX, boot_script, "Invalid path: %s" % boot_script)
 
-
     def _validate_snowball_startup_files_config(self):
         snowball_startup_files_config = self.snowball_startup_files_config
         if snowball_startup_files_config is not None:
@@ -797,8 +795,9 @@ class Config(object):
         if u_boot_package is not None:
             self._assert_matches_pattern(
                 self.PACKAGE_REGEX, u_boot_package, "Invalid value in %s in " \
-                    "the [%s] section: %s" % (self.U_BOOT_PACKAGE_KEY,
-                                              self.MAIN_SECTION, u_boot_package))
+                    "the [%s] section: %s" % (
+                        self.U_BOOT_PACKAGE_KEY, self.MAIN_SECTION,
+                        u_boot_package))
 
     def _validate_spl_package(self):
         spl_package = self.spl_package
