@@ -8,12 +8,12 @@
 # modify it under the terms of the GNU General Public License
 # as published by the Free Software Foundation; either version 2
 # of the License, or (at your option) any later version.
-# 
+#
 # Linaro Image Tools is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-# 
+#
 # You should have received a copy of the GNU General Public License
 # along with Linaro Image Tools; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
@@ -169,7 +169,7 @@ class AptSourceFixture(object):
 
     @property
     def sources_entry(self):
-        return "file:" + os.path.abspath(self.rootdir) +" ./"
+        return "file:" + os.path.abspath(self.rootdir) + " ./"
 
 
 class ConfigFileFixture(object):
@@ -382,7 +382,8 @@ class IsHardwarePack(Matcher):
             if self.package_spec:
                 dep_package_matcher = dep_package_matcher.update(
                     depends=MatchesPackageRelationshipList(
-                        [Equals(p.strip()) for p in self.package_spec.split(',')]))
+                        [Equals(p.strip())
+                         for p in self.package_spec.split(',')]))
             package_matchers.append(dep_package_matcher)
             matchers.append(HardwarePackHasFile(
                 "pkgs/Packages",
