@@ -3,7 +3,7 @@
 # Author: Guilherme Salgado <guilherme.salgado@linaro.org>
 #
 # This file is part of Linaro Image Tools.
-# 
+#
 # Linaro Image Tools is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -23,7 +23,8 @@ import os
 
 from linaro_image_tools import cmd_runner
 from linaro_image_tools.media_create.boards import board_configs
-from linaro_image_tools.media_create.android_boards import android_board_configs
+from linaro_image_tools.media_create.android_boards import (
+    android_board_configs)
 from linaro_image_tools.__version__ import __version__
 
 
@@ -66,6 +67,7 @@ def get_version():
         qemu_version = "Cannot find %s." % qemu_path
     return "%s\n: %s" % (__version__, qemu_version)
 
+
 def add_common_options(parser):
     parser.add_argument(
         '--extra-boot-args', dest='extra_boot_args', required=False,
@@ -74,6 +76,7 @@ def add_common_options(parser):
         '--extra-boot-args-file', dest='extra_boot_args_file',
         required=False, help=('File containing extra boot arguments.'))
 
+
 def get_args_parser():
     """Get the ArgumentParser for the arguments given on the command line."""
     parser = argparse.ArgumentParser(version='%(prog)s ' + get_version())
@@ -156,11 +159,13 @@ def get_args_parser():
     parser.add_argument(
         '--nocheck-mmc', dest='nocheck_mmc',
         action='store_true',
-        help='Assume yes to the question "Are you 100%% sure, on selecting [mmc]"')
-    
+        help=('Assume yes to the question "Are you 100%% sure, '
+              'on selecting [mmc]"'))
+
     add_common_options(parser)
     return parser
 
+
 def get_android_args_parser():
     """Get the ArgumentParser for the arguments given on the command line."""
     parser = argparse.ArgumentParser(version='%(prog)s ' + get_version())
