@@ -3,7 +3,7 @@
 # Author: Guilherme Salgado <guilherme.salgado@linaro.org>
 #
 # This file is part of Linaro Image Tools.
-# 
+#
 # Linaro Image Tools is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -32,6 +32,7 @@ from linaro_image_tools.utils import (
 # functions would only be called after l-m-c.py exits.
 local_atexit = []
 
+
 def prepare_chroot(chroot_dir, tmp_dir):
     """Prepares a chroot to run commands in it (networking and QEMU setup)."""
     chroot_etc = os.path.join(chroot_dir, 'etc')
@@ -42,8 +43,10 @@ def prepare_chroot(chroot_dir, tmp_dir):
         copy_file('/usr/bin/qemu-arm-static',
                   os.path.join(chroot_dir, 'usr', 'bin'))
 
+
 def install_hwpacks(
-    chroot_dir, tmp_dir, tools_dir, hwpack_force_yes, verified_files, *hwpack_files):
+    chroot_dir, tmp_dir, tools_dir, hwpack_force_yes, verified_files,
+    *hwpack_files):
     """Install the given hwpacks onto the given chroot."""
     prepare_chroot(chroot_dir, tmp_dir)
 
@@ -76,7 +79,8 @@ def install_hwpacks(
             hwpack_verified = False
             if os.path.basename(hwpack_file) in verified_files:
                 hwpack_verified = True
-            install_hwpack(chroot_dir, hwpack_file, hwpack_force_yes or hwpack_verified)
+            install_hwpack(chroot_dir, hwpack_file,
+                           hwpack_force_yes or hwpack_verified)
     finally:
         run_local_atexit_funcs()
 
