@@ -3,7 +3,7 @@
 # Author: Guilherme Salgado <guilherme.salgado@linaro.org>
 #
 # This file is part of Linaro Image Tools.
-# 
+#
 # Linaro Image Tools is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -110,12 +110,14 @@ def update_network_interfaces(root_disk, board_config):
         config = ''
     for interface in interfaces:
         if interface not in config:
-            config += "auto %(if)s\niface %(if)s inet dhcp\n" % ({ 'if': interface })
+            config += "auto %(if)s\niface %(if)s inet dhcp\n" % (
+                {'if': interface})
     if config != '':
         write_data_to_protected_file(if_path, config)
 
 
-def create_flash_kernel_config(root_disk, mmc_device_id, boot_partition_number):
+def create_flash_kernel_config(root_disk, mmc_device_id,
+                               boot_partition_number):
     """Create a flash-kernel.conf file under root_disk/etc.
 
     Uses the given partition number to figure out the boot partition.
@@ -157,7 +159,7 @@ def has_space_left_for_swap(root_disk, swap_size_in_mega_bytes):
     """Is there enough space for a swap file in the given root disk?"""
     statvfs = os.statvfs(root_disk)
     free_space = statvfs.f_bavail * statvfs.f_bsize
-    swap_size_in_bytes = int(swap_size_in_mega_bytes) * 1024**2
+    swap_size_in_bytes = int(swap_size_in_mega_bytes) * 1024 ** 2
     if free_space >= swap_size_in_bytes:
         return True
     return False
